@@ -141,6 +141,14 @@ max_length_mult = {
     "exasol": 1,
 }
 
+python_type_dict = {
+    "ch": {"str": "Nullable(String)", "bool": "UInt8", "int": "UInt32"},
+    "pg": {},
+    "mysql": {},
+    "vertica": {},
+    "exasol": {},
+}
+
 # types update to insert then
 update_types_dict = {
     "ch": {"int32": "int", "int8": "bool", "str": "str", "float": "float"},
@@ -344,7 +352,7 @@ class FieldsConverterOneWay:
             self.meta = MetaData(bind=engine, schema=self.schema)
         else:
             self.meta = MetaData(bind=engine)
-
+        self.quote_char = quotes_dict[self.db]
         if len(self.tables) > 0:
             self.meta.reflect(only=self.tables)
         else:
@@ -401,6 +409,39 @@ class FieldsConverterOneWay:
         ]
         return dict(zip(columns, types))
 
+    def create_table(self, fields_python, table_name, to_create=True, dir=None):
+        """create tables using python types"""
+        txt = "CREATE TABLE IF NOT EXISTS {schema}.{table} (".format(
+            schema=self.schema, table=table_name
+        )
+        types_conv = python_type_dict[self.db]
+        res_list = []
+        for field in fields_python:
+            type_python = fields_python[field]
+            if type_python in types_conv:
+                type_sql = types_conv[type_python]
+            else:
+                type_sql = types_conv["str"]
+            res_list.append(self.quote_char + field + self.quote_char + " " + type_sql)
+        txt += ",".join(res_list)
+        txt += ")"
+        if to_create:
+            self.conn.execute(txt)
+            logging.info("creating table {} is successfull".format(table_name))
+        if dir is not None:
+            f = open(
+                dir
+                + "/"
+                + self.schema
+                + "_"
+                + table_name.replace("_date", "")
+                + ".sql",
+                "w",
+            )
+            f.write(txt)
+            f.close()
+        return txt
+
 
 class FieldsConverter:
     def __init__(self, sql_credentials, from_db, to_db, debug=True, tables=None):
@@ -541,8 +582,8 @@ class FieldsConverter:
             if sort_part is not None:
                 add_part = generate_sort_part_vertica(sort_part, date_field=date_field)
                 if (
-                    date_field != ""
-                    and fields[date_field].lower().find("not null") == -1
+                        date_field != ""
+                        and fields[date_field].lower().find("not null") == -1
                 ):
                     fields[date_field] += " not null"
         elif self.to_db == "exasol":
